@@ -12,7 +12,7 @@
 extern SEXP R_git_ahead_behind(SEXP, SEXP, SEXP);
 extern SEXP R_git_branch_current(SEXP);
 extern SEXP R_git_branch_exists(SEXP, SEXP, SEXP);
-extern SEXP R_git_branch_list(SEXP);
+extern SEXP R_git_branch_list(SEXP, SEXP);
 extern SEXP R_git_branch_set_upstream(SEXP, SEXP, SEXP);
 extern SEXP R_git_checkout_branch(SEXP, SEXP, SEXP);
 extern SEXP R_git_cherry_pick(SEXP, SEXP);
@@ -72,7 +72,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"R_git_ahead_behind",       (DL_FUNC) &R_git_ahead_behind,       3},
   {"R_git_branch_current",     (DL_FUNC) &R_git_branch_current,     1},
   {"R_git_branch_exists",      (DL_FUNC) &R_git_branch_exists,      3},
-  {"R_git_branch_list",        (DL_FUNC) &R_git_branch_list,        1},
+  {"R_git_branch_list",        (DL_FUNC) &R_git_branch_list,        2},
   {"R_git_branch_set_upstream",(DL_FUNC) &R_git_branch_set_upstream,3},
   {"R_git_checkout_branch",    (DL_FUNC) &R_git_checkout_branch,    3},
   {"R_git_cherry_pick",        (DL_FUNC) &R_git_cherry_pick,        2},
